function [FileList] = gdig(FilePath,FileList,FileExt,verbose)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % -----USAGE-----
    % 1) Method call with inputs:       when the method is called with two
    % inputs, they must follow the below convention.
    % -----DEFS-----
    % --------------------------------------------------
    % INPUTS: FilePath  =   the path to start recursivly searching for
    %                       files.
    %         FileList  =   the list of files found via the searching
    %         FileExt   =   cell array containing extensions 
    %         verbose   =   verbose flag for reporting 
    % --------------------------------------------------
    % OUTPUT: FileList  =   cell array containing the list of files found
    %                       during the search.
    % --------------------------------------------------
    % ----EXAMPLE-----
    % FilePath = 'C:\';
    % FileList = {};
    % FileExt = {'tif','TIF'};
    % FileList = gdig(FilePath,FileList,FileExt,1);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
try
    %%%%%%%%%%%%%%%%%%%%
    %%% directory of input FilePath
    dirList = dir(FilePath);
    ridx = strcmp({dirList.name},'.') | strcmp({dirList.name},'..');
    dirList(ridx) = [];    
    %%%%%%%%%%%%%%%%%%%%
    % if not empty
    if size(dirList,2) ~= 0
        %%%%%%%%%%%%%%%%%%%%
        % for each object in the list
        for listing = 1:size(dirList,1)
            %%%%%%%%%%%%%%%%%%%%
            % init the next path
            current_Path = [FilePath dirList(listing).name];            
            typed_path = regexprep(current_Path,filesep,[filesep filesep filesep]);
            %%%%%%%%%%%%%%%%%%%%
            % if directory
            if dirList(listing).isdir
                %%%%%%%%%%%%%%%%%%%%
                % report 
                if verbose
                    fprintf(['Looking at:' typed_path '\n']);
                end
                %%%%%%%%%%%%%%%%%%%%
                % call gdig - recursive
                FileList = gdig([current_Path filesep],FileList,FileExt,verbose);
            %%%%%%%%%%%%%%%%%%%%
            % if file
            else
                %%%%%%%%%%%%%%%%%%%%
                % look for the .
                tidx = strfind(dirList(listing).name,'.');
                %%%%%%%%%%%%%%%%%%%%
                % if not empty and a type in the list - add
                if ~isempty(tidx)                    
                    if any(strcmp(FileExt,dirList(listing).name(tidx(end)+1:end))) || any(strcmp(FileExt,'*'))
                        FileList{end+1,1} = current_Path;
                    end
                end
            end
        end
    end
catch ME
    ME
end

%{

%}
