function [] = seedSize_main(fileName,outPath)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % -----USAGE-----
    % 1) Method call with no inputs:    when the method is called with no inputs,
    % such as seedSize_main(), the user will be prompted with a dialog box.
    % For the first dialog box, the user must first select the directory 
    % which contains the images. For the second dialog box, the user must select
    % the path which will contain the results.
    
    % 2) Method call with inputs:       when the method is called with two
    % inputs, they must follow the below convention.
    %
    % 
    % -----DEFS-----
    % INPUTS: fileName  =   cell array of image file names. The images should
    %                       be in tiff format.
    %         outPath   =   matlab string representing location for saving
    %                       the resulting CSV files.
    % FLAGS:  sample    =   value for downsampling the image. When
    %                       obtaining the histogram for Otsu's threshold,
    %                       the images are read from disk.  This value
    %                       determines the amount of downsampling which
    %                       will occur during this process.    
    %         disp      =   flag for displaying a wait bar during the
    %                       computation.
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%
    % FLAGS
    sample = 1;
    disp = 1;
    %%%%%%%%%%%%%%%%%%%%
    try
        warning off;
        %%%%%%%%%%%%%%%%%%%%    
        % SELECT INPUT 
        if nargin ==0
            %%%%%%%%%%%%%%%%%%%%
            % select input path
            inPath = uigetdir();
            %%%%%%%%%%%%%%%%%%%%
            % gdig
            fileName = gdig([inPath filesep],{},{'TIF','tif'},1);
            %%%%%%%%%%%%%%%%%%%%
            % scan for threshold
            outPath = uigetdir();    
        end
        %%%%%%%%%%%%%%%%%%%%
        % number of images
        NUMFILE = numel(fileName);
        
        %%%%%%%%%%%%%%%%%%%%
        % display
        if disp
            h = waitbar(0,'Calculating threshold.........');
        end
        
        %%%%%%%%%%%%%%%%%%%%
        % scan for threshold        
        for i = 1:NUMFILE        
            info = imfinfo(fileName{i});
            I = imread(fileName{i},'PixelRegion',{[1 sample info.Height],[1 sample info.Width]});
            waitbar(i/NUMFILE,h,'Calculating threshold.........');
            level(i) = graythresh(I);
            fprintf(['Done scanning:' num2str(i) ':' num2str(NUMFILE) '\n']);
        end
        
        %%%%%%%%%%%%%%%%%%%%
        % display
        if disp
            close(h);
        end

        %%%%%%%%%%%%%%%%%%%%
        % display
        if disp
            h = waitbar(0,'Measuring seed properties......');
        end
        
        
        %%%%%%%%%%%%%%%%%%%%
        % get the common threshold
        % for each image, load-threshold-measure        
        for i = 1:NUMFILE
            %%%%%%%%%%%%%%%%%%%%
            % read the whole image
            I = imread(fileName{i});
            % image information
            info = imfinfo(fileName{i});
            
            %%%%%%%%%%%%%%%%%%%%
            % measure with indiv threshold
            MI = measureI(I,info.BitsPerSample,level(i));        
            [pth nm ext] = fileparts(fileName{i});
            tmp_oPath = [outPath filesep 'individual' filesep];
            mkdir(tmp_oPath);
            csvwrite([tmp_oPath nm '_I.txt'],MI.SeedSheet);
            
            %%%%%%%%%%%%%%%%%%%%            
            % measure with group threshold
            MC = measureI(I,info.BitsPerSample,mean(level));
            [pth nm ext] = fileparts(fileName{i});
            tmp_oPath = [outPath filesep 'common' filesep];
            mkdir(tmp_oPath);
            csvwrite([tmp_oPath nm '_C.txt'],MC.SeedSheet);
            
            %%%%%%%%%%%%%%%%%%%%
            % report
            if disp
                h = waitbar(i/NUMFILE,h,'Measuring seed properties......');
            end
        end
        
        %%%%%%%%%%%%%%%%%%%%
        % display
        if disp
            close(h);
        end
        
    catch ME
        ME
    end
end